@@ -34,12 +34,10 @@ class Parameter():
 
     def verification(self, checking: dict, verify: dict) -> bool:
         if not set(verify.keys()).issubset(set(checking.keys())):
-            logging.warning('请求参数不完整: {0} 对比 {1}'.format(
-                json.dumps(checking), json.dumps(verify)))
+            logging.warning('请求参数不完整: {0}'.format(json.dumps(checking)))
             return False
         for _k, _v in checking.items():
             if type(_v) != verify[_k]:
-                logging.warning('请求参数类型校验失败: {0} 对比 {1}'.format(
-                    json.dumps(checking), json.dumps(verify)))
+                logging.warning('请求参数类型校验失败: {0}'.format(json.dumps(checking)))
                 return False
         return True
